// ==================================================================
//
// Program Name
//  JMailer
//
// Last date of modification
//  15 April 2001
//
// Description
//  This java class will send an email message to one or more
//  recipient. Informattion about the email can be stored in a
//  properties file or passed to JMailer via the command line.
//  JMailer can be used as a Running Man action in CCC.
//
//  If you put most of the information in the properties file
//  then you do not have to specify it and the command line.
//
//  Also, the command line parameters will override the parameters
//  in the properties file.  Except for the "-t" keyword.  It
//  adds to the recipients in the properties file rather than
//  overriding them.
//
// Author
//  Roger Lacroix
//
// Sample Command Line Parameters:
//  -h my-smtp-server -f joe.blow@yahoo.com -t jane.doe@yahoo.com -s "email Subject" -m "This is the email message body text."
//
// ------------------------------------------------------------------
import java.util.*;
import java.io.*;

public class JMailer
{

   public JMailer()
   {
      super();
   }

   //
   private void ReadConfigurationFile(EmailManager Email)
   {
      //File that contains configuration information
      String configFileName = "jmailer.properties";
      Properties props = new Properties();
      String value;

      try
      {
         FileInputStream in = new FileInputStream(configFileName);
         props.load(in);

         //Read boolean value from configuration file
         value = props.getProperty("SendEmail");
         Email.SetDoSendMail(value);

         //
         value = props.getProperty("EmailSubject");
         Email.SetEmailSubject(value);

         //
         value = props.getProperty("EmailBody");
         Email.SetEmailBody(value);

         // Setup mail server
         value = props.getProperty("SMTPHostAddress");
         Email.SetSMTPHostAddress(value);

         //
         value = props.getProperty("SMTPFromAddress");
         Email.SetSMTPFromEmailAddress(value);

         //
         value = props.getProperty("ToEmailName");
         Email.SetToAddress(value);
      }
      catch (IOException ex)
      {
         System.out.println("Exception: " + ex);
      }

   }  // end method

   private void ReadCmdLineParms(String[] args, EmailManager Email) throws IllegalArgumentException
   {
      String value;
      Hashtable params = null;
      params = new Hashtable(10);
      if (args.length > 0 && (args.length % 2) == 0)
      {
        for (int i = 0; i < args.length; i+=2)
        {
         params.put(args[i], args[i+1]);
        }
      }
      else
      {
        throw new IllegalArgumentException();
      }

      value = (String) params.get("-h");
      if ( value != null )
      {
         Email.SetSMTPHostAddress(value);
      }

      value = (String) params.get("-f");
      if ( value != null )
      {
         Email.SetSMTPFromEmailAddress(value);
      }

      value = (String) params.get("-t");
      if ( value != null )
      {
         Email.SetToAddress(value);
      }

      value = (String) params.get("-s");
      if ( value != null )
      {
         Email.SetEmailSubject(value);
      }

      value = (String) params.get("-m");
      if ( value != null )
      {
         Email.SetEmailBody(value);
      }
   }

   private void VerifyParameters(EmailManager Email) throws IllegalArgumentException
   {
      if ( (Email.GetSMTPHostAddress() == null)      ||
           (Email.GetSMTPFromEmailAddress() == null) ||
           (Email.GetToAddress() == null)            ||
           (Email.GetEmailSubject() == null)         ||
           (Email.GetEmailBody() == null) )
      {
         throw new IllegalArgumentException();
      }
   }

  // MAIN
  public static void main(String[] args)
  {
     JMailer jmailer = new JMailer();
     EmailManager Email = new EmailManager();

     try
     {
        Email.SetDoSendMail("true");  // set the default as true.

        jmailer.ReadConfigurationFile(Email);
        jmailer.ReadCmdLineParms(args,Email);
        jmailer.VerifyParameters(Email);
        Email.SendEmail();
     }
     catch (IllegalArgumentException e)
     {
        System.out.println("Usage: java JMailer <-h host> <-f fromAddress> <-t toAddress> <-s emailSubject> <-m emailMessageBody>");
     }
     catch(Exception x)
     {
        System.out.println("Oops - exception: " + x.getMessage() + ".");
     }
   }

} // end class tester

